pyvisco.prony
=============

.. automodule:: pyvisco.prony

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      E_freq_norm
      E_relax_norm
      GMaxw_temp
      calc_GMaxw
      discretize
      fit
      fit_freq
      fit_time
      ls_res
      plot_GMaxw
      plot_GMaxw_temp
      plot_dis
      plot_fit
      plot_param
      split_x0
   
   

   
   
   

   
   
   



